| Title: | Lightweight Tools to Create Sea Level Rise Projections for the Tampa Bay Region |
|---|---|
| Description: | Lightweight tools to download data and create plots for sea level rise projections in the Tampa Bay region. Plots are produced to support recommendations of the Climate Science Advisory Panel facilitated by the Tampa Bay Estuary Program. Data are from NOAA Tides and Currents web page <https://tidesandcurrents.noaa.gov/> and the Interagency Sea Level Rise Scenario Tool <https://sealevel.nasa.gov/task-force-scenario-tool>. |
| Authors: | Marcus Beck [aut, cre] (ORCID: <https://orcid.org/0000-0002-4996-0059>) |
| Maintainer: | Marcus Beck <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.3.0 |
| Built: | 2026-05-23 08:52:00 UTC |
| Source: | https://github.com/tbep-tech/slrcsap |
Get Sea Level Rise (SLR) scenario
get_scenario( id = 520, scenario = c("IntLow", "Int", "IntHigh"), method = "curl", quiet = TRUE )get_scenario( id = 520, scenario = c("IntLow", "Int", "IntHigh"), method = "curl", quiet = TRUE )
id |
numeric, gauge number. Default is 520 (St. Petersburg, FL). |
scenario |
character, SLR scenario. Default is |
method |
character, download method. Default is |
quiet |
logical, suppress download messages. Default is |
Information from https://sealevel.nasa.gov/task-force-scenario-tool?psmsl_id=520, by default. Results are SLR in meters and feet for the intermediate low, intermediate, and intermediate high scenarios based on recommended scenarios from the Climate Science Advisory Panel. Full options for scenarios are 'Low', 'IntLow', 'Int', 'IntHigh', and 'High'. Values for SLR are relative change from 2020.
A data frame with columns for id, scenario, year, SLR in meters, and SLR in feet.
dat <- get_scenario() head(dat)dat <- get_scenario() head(dat)
Get monthly Mean Sea Level (MSL) data for selected gauge
get_sealevel(gauge = 8726520)get_sealevel(gauge = 8726520)
gauge |
numeric, gauge number. Default is 8726520 (St. Petersburg, FL). |
Information from https://tidesandcurrents.noaa.gov using the URL https://tidesandcurrents.noaa.gov/sltrends/data/8726520_meantrend.txt, by default. Results are monthly Mean Sea Level (MSL) in meters and feet, with the seasonal cycle removed.
A data frame with columns for gauge, year, month, date, MSL in meters, and MSL in feet.
dat <- get_sealevel(gauge = 8726520) head(dat)dat <- get_sealevel(gauge = 8726520) head(dat)
Plot sea level scenario data
plot_scenario( dat, cols = c("deepskyblue", "orange", "red"), units = "ft", linewidth = 1, caption = TRUE, xrng = c(2020, 2100), xbrk = 10, yrng = NULL, ybrk = 7, plotly = FALSE )plot_scenario( dat, cols = c("deepskyblue", "orange", "red"), units = "ft", linewidth = 1, caption = TRUE, xrng = c(2020, 2100), xbrk = 10, yrng = NULL, ybrk = 7, plotly = FALSE )
dat |
Input data from |
cols |
character, color palette for the lines. Default is |
units |
character, units for the y-axis. Default is |
linewidth |
numeric, line width. Default is |
caption |
logical, add caption with source. Default is |
xrng |
numeric, x-axis range. Default is |
xbrk |
numeric, number of x-axis breaks. Default is |
yrng |
numeric, y-axis range as two values. Default is |
ybrk |
numeric, number of y-axis breaks. Default is |
plotly |
logical, if |
A ggplot object
dat <- get_scenario() plot_scenario(dat)dat <- get_scenario() plot_scenario(dat)
Plot sea level data
plot_sealevel( dat, col = "deepskyblue", units = "ft", caption = TRUE, xrng = NULL, xbrk = 10, yrng = NULL, ybrk = 5, plotly = FALSE )plot_sealevel( dat, col = "deepskyblue", units = "ft", caption = TRUE, xrng = NULL, xbrk = 10, yrng = NULL, ybrk = 5, plotly = FALSE )
dat |
Input data from |
col |
character, color for the line. Default is |
units |
character, units for the y-axis. Default is |
caption |
logical, add caption with source. Default is |
xrng |
Date, x-axis range as two values. Default is |
xbrk |
numeric, number of x-axis breaks. Default is |
yrng |
numeric, y-axis range as two values. Default is |
ybrk |
numeric, number of y-axis breaks. Default is |
plotly |
logical, if |
a ggplot object
dat <- get_sealevel() plot_sealevel(dat)dat <- get_sealevel() plot_sealevel(dat)